<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin Görsel Görüntüleyici</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Sürüm:</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Deepin Görsel Görüntüleyici, modern ve sade görsel yöneticisi.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Görsel yönetimi, görsel görüntüleme ve basit görsel düzenleme özelliklerini sunar.</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>görsel</translation>
    </message>
    <message>
        <source>images</source>
        <translation>görsel</translation>
    </message>
    <message>
        <source>album</source>
        <translation>albüm</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>albüm</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Eşitleme yönetimi</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Eşitleme:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Yeni albüm</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Adsız</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Son içe aktarılan</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Sık kullandıklarım</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Bu albümü silmek istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Sık kullandıklarım</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Zaman tüneli</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Eşitlenecek klasörü ekleyebilir ya da görselleri sürükleyip zaman tüneline bırakabilirsiniz</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Adsız</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görüntüle</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Saydam sunumu</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Yeniden adlandır</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin Görsel Görüntüleyici</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Görseller</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Görselleri albüme eklemek istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Eşitle ve Oluştur</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Eşitle</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Eşitleme listesine eklemek ve bu klasörün adını taşıyan bir albüm oluşturmak istediğinize emin misiniz?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Dışa aktarıldı</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Dışa aktarılamadı</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Görselleri çöpe atmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Görsel bilgileri</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Bu dosyada birden fazla sayfa var. Lütfen tüm sayfaları görüntülemek için Evince uygulamasını kullanın.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Görüntüle</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tam Ekran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Saydam sunumu</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Yazdır</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Panoya kopyala</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Çöpe at</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Albümden kaldır</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sık kullanılanlara ekle</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sık kullanılanlardan çıkar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Saat yönünde döndür</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Saat yönünün tersine döndür</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Duvar kağıdı olarak ayarla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Dosya yöneticisinde görüntüle</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Görsel bilgileri</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Eşitlenecek klasörü ekleyebilir ya da görselleri sürükleyip zaman tüneline bırakabilirsiniz</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Albüme ekle</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Yeni albüme ekle</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Klasörü Aç</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Görseli görüntüleme izniniz yok</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tür</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>Oluşturulma tarihi</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Değiştirilme tarihi</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Çözünürlük</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Dosya boyutu</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Renk aralığı</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Pozlama kipi</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Pozlama programı</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Pozlama süresi</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flaş</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Diyafram</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Odak uzaklığı</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>En yüksek diyafram</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Ölçüm kipi</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Beyaz dengesi</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Flaş dengeleme</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kamera modeli</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Lens modeli</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Ölçeklendirme yok</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Sayfayı görsele göre ayarla</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Görseli sayfaya göre ayarla</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Şuna ölçeklendir:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milimetre</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Santimetre</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>İnç</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Görsel Konumu</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Ölçeklendirme</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Görsel Ayarları</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Panjur</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Değiştirici</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Kayar</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Halka</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Klasör Seçin</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Bu klasörün eşitlenmesi devre dışı bırakılmış</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Klasör ekle</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Klasör Eşitleme Yönetimi</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Klasör listesi boş</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Eşitlemeyi iptal et</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Görseller</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Aygıt kaldırıldı</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Bu klasör artık yok</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Hesaplanıyor...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Görsel Görüntüleniyor</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Albüm</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görüntüle</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tam Ekran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Saydam sunumu</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Sunumu bitir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Çöpe at</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Albümden kaldır</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sık kullanılanlara ekle</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sık kullanılandan çıkar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Saat yönünde döndür</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Saat yönünün tersine döndür</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Duvar kağıdı olarak ayarla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Dosya yöneticisinde görüntüle</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Görsel bilgileri</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Önceki</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Sonraki</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Önceki ekran</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Sonraki ekran</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Yeni albüm</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Yeniden adlandır</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çık</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Kısayolları görüntüle</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Lütfen yeni bir kısayol yazın</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Kısayollar</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Görseli Görüntüle</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Albüm</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Varsayılanları Geri Yükle</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Görüntüle</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tam Ekran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Saydam sunumu</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Sunumu bitir</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Yazdır </translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Çöpe at</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Albümden kaldır</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sık kullanılanlara ekle</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sık kullanılandan çıkar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Saat yönünde döndür</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Saat yönünün tersine döndür</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Duvar kağıdı olarak ayarla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Dosya yöneticisinde görüntüle</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Görsel bilgileri</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Yeni albüm</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Yeniden adlandır</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Sunumu bitir</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Duraklat/Oynat</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Saydam Ayarları</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Geçiş etkisi</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Süre</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Geçiş süresi</translation>
    </message>
    <message>
        <source>second</source>
        <translation>saniye</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Görsel yönetimi</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Sık kullandıklarım</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Boyut</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Pencereye sığdır</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Saat yönünün tersine döndür</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Saat yönünde döndür</translation>
    </message>
    <message>
        <source>Throw to Trash</source>
        <translation>Çöpe at</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sık kullanılandan çıkar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sık kullanılanlara ekle</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Herhangi bir görsel dosyası bulunamadı</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 görsel</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 görsel</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Eşitleme yönetimi</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Eşitleniyor:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Albüm</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Eşitlenecek klasörü ekleyebilir ya da görselleri sürükleyip zaman tüneline bırakabilirsiniz</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Albüme ekle</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Yeni albüme ekle</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görüntüle</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tam Ekran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Saydam sunumu</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Yazdır</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Panoya kopyala</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Çöpe at</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sık kullanılanlara ekle</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sık kullanılanlardan çıkar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Saat yönünde döndür</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Saat yönünün tersine döndür</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Duvar kağıdı olarak ayarla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Dosya yöneticisinde görüntüle</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Görsel bilgileri</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Saydam Ayarları</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Etki</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Süre</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Kısayollar</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görüntüle</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Albüm</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>gg AAAA yyyy</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Sık kullandıklarım</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Son içe aktarılan</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Yeni albüm</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Deepin Görsel Görüntüleyici, modern ve sade görsel yöneticisi.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Görsel yönetimi, görsel görüntüleme ve basit görsel düzenleme özelliklerini sunar.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Koyu tema</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Zaman tüneli</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Albüme ekle</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Yeni albüme ekle</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Tam ekrandan çık</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tam Ekran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Saydam sunumu</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Yazdır</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Panoya kopyala</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Çöpe at</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Albümden kaldır</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sık kullanılanlara ekle</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Sık kullanılanlardan çıkar</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Gezinme penceresini görüntüle</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Gezinme penceresini gizle</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Saat yönünde döndür</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Saat yönünün tersine döndür</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Duvar kağıdı olarak ayarla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Dosya yöneticisinde görüntüle</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Görsel bilgileri</translation>
    </message>
</context>
</TS>